@@ -8,7 +8,7 @@ use anchor_lang::prelude::*;
 use vipers::prelude::*;
 
 impl<'info> Validate<'info> for CreateOperator<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(
             self.operator,
             self.rewarder.pending_authority,
@@ -19,21 +19,21 @@ impl<'info> Validate<'info> for CreateOperator<'info> {
 }
 
 impl<'info> Validate<'info> for SetRole<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(self.operator.admin, self.admin, Unauthorized);
         Ok(())
     }
 }
 
 impl<'info> Validate<'info> for WithDelegate<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(self.operator.rewarder, self.rewarder, "operator.rewarder");
         Ok(())
     }
 }
 
 impl<'info> Validate<'info> for DelegateSetAnnualRewards<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.with_delegate.validate()?;
         assert_keys_eq!(
             self.with_delegate.operator.rate_setter,
@@ -45,7 +45,7 @@ impl<'info> Validate<'info> for DelegateSetAnnualRewards<'info> {
 }
 
 impl<'info> Validate<'info> for DelegateCreateQuarry<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.with_delegate.validate()?;
         assert_keys_eq!(
             self.with_delegate.operator.quarry_creator,
@@ -57,7 +57,7 @@ impl<'info> Validate<'info> for DelegateCreateQuarry<'info> {
 }
 
 impl<'info> Validate<'info> for DelegateSetRewardsShare<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.with_delegate.validate()?;
         assert_keys_eq!(
             self.with_delegate.operator.share_allocator,
@@ -69,7 +69,7 @@ impl<'info> Validate<'info> for DelegateSetRewardsShare<'info> {
 }
 
 impl<'info> Validate<'info> for DelegateSetFamine<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.with_delegate.validate()?;
         assert_keys_eq!(
             self.with_delegate.operator.share_allocator,
